<?php
require_once 'config.php';
checkAccess(['admin', 'programmer']);

$data = $REQUEST_DATA;

if (!isset($data['rif'])) response(["error" => "RIF faltante"], 400);

try {
    $stmt = $pdo->prepare("DELETE FROM providers WHERE rif = ?");
    $stmt->execute([$data['rif']]);
    logSystemAction("ELIMINÓ Proveedor RIF: " . $data['rif'], "PROVEEDORES");
    response(["success" => true]);
} catch (PDOException $e) {
    response(["error" => "No se puede eliminar: El proveedor tiene transacciones vinculadas."], 409);
}