<?php
require_once 'config.php';
checkAccess(['programmer']);

try {
    $pdo->exec("TRUNCATE TABLE system_audit_logs");
    logSystemAction("RESETEO DE BITÁCORA", "SEGURIDAD", true);
    response(["success" => true]);
} catch (PDOException $e) {
    response(["error" => $e->getMessage()], 500);
}
?>