<?php
/**
 * SAC 2025 - DELETE PENDING BILL ENGINE v6.5
 * Permite eliminar facturas del sistema con registro en bitácora.
 */
require_once 'config.php';

// Verificación de seguridad: Solo niveles administrativos
checkAccess(['admin', 'programmer', 'board']);

$data = $REQUEST_DATA;

if (!isset($data['id'])) {
    response(["error" => "ID de factura no proporcionado"], 400);
}

try {
    // 1. Obtener datos de la factura antes de borrar para el log
    $stmtInfo = $pdo->prepare("SELECT provider, description, amount_bs FROM pending_bills WHERE id = ?");
    $stmtInfo->execute([$data['id']]);
    $bill = $stmtInfo->fetch();

    if ($bill) {
        // 2. Ejecutar eliminación física
        $stmt = $pdo->prepare("DELETE FROM pending_bills WHERE id = ?");
        $stmt->execute([$data['id']]);
        
        // 3. Registrar en Auditoría
        $msg = "ELIMINÓ factura: " . $bill['provider'] . " (" . $bill['description'] . ") por Bs." . number_format($bill['amount_bs'], 2, ',', '.');
        logSystemAction($msg, "BALANCE");

        response(["success" => true, "message" => "Registro eliminado correctamente"]);
    } else {
        response(["error" => "La factura ya no existe en la base de datos"], 404);
    }
} catch (PDOException $e) {
    response(["error" => "Error de base de datos: " . $e->getMessage()], 500);
}
?>