<?php
require_once 'config.php';

/**
 * SAC 2026 - GET USERS (HARDENED) v7.5
 * REPARACIÓN NUCLEAR: Inclusión de Telegram ID en el flujo de datos.
 */
try {
    checkAccess(['admin', 'programmer']);
} catch (Exception $e) {
    response(["error" => "No autorizado"], 401);
}

try {
    // Se añade telegram_chat_id con su respectivo alias camelCase para compatibilidad con el frontend
    $stmt = $pdo->query("SELECT 
                            id, 
                            username, 
                            full_name as fullName, 
                            role, 
                            email, 
                            cedula, 
                            phone, 
                            status, 
                            expires_at as expiresAt,
                            telegram_chat_id as telegramChatId 
                        FROM users 
                        ORDER BY full_name ASC");
    $users = $stmt->fetchAll();
    
    foreach($users as &$u) {
        $u['status'] = (strtolower($u['status']) === 'active' || $u['status'] === 'Activo') ? 'Activo' : 'Inactivo';
    }
    
    response($users);
} catch (PDOException $e) {
    response(["error" => "Error de comunicación con el motor de base de datos."], 500);
}
?>