<?php
/**
 * SAC 2026 - MARK REPORT AS SEEN
 * Arquitecto: Andres Mathison
 * Objetivo: Marcar un reporte de pago como visto por el administrador.
 */
require_once 'config.php';

checkAccess(['admin', 'programmer', 'board']);

$data = json_decode(file_get_contents("php://input"), true);

if (!$data || !isset($data['id'])) {
    response(["error" => "ID de deuda no proporcionado"], 400);
}

try {
    $stmt = $pdo->prepare("UPDATE property_debts SET report_seen = 1 WHERE id = ?");
    $stmt->execute([$data['id']]);
    
    response(["success" => true]);

} catch (PDOException $e) {
    response(["error" => "Error al actualizar reporte: " . $e->getMessage()], 500);
}
?>