<?php
require_once 'config.php';

/**
 * SAC 2026 - LOGOUT HANDLER v4.2
 * Cierra la sesión del usuario de forma segura.
 */

session_start();
session_unset();
session_destroy();

// Limpiar cookies de sesión si existen
if (ini_get("session.use_cookies")) {
    $params = session_get_cookie_params();
    setcookie(session_name(), '', time() - 42000,
        $params["path"], $params["domain"],
        $params["secure"], $params["httponly"]
    );
}

response(["success" => true, "message" => "Sesión cerrada correctamente"]);
?>